CloudRecordIndex class

Constructors

CloudRecordIndex({required int startTimestampSecond, required int endTimestampSecond, required int durationSecond, required String storageId})
CloudRecordIndex.fromJson(Map<String, dynamic> json)
factory

Properties

durationSecond int
final
endTimestampSecond int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestampSecond int
final
storageId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited