FeedingTimer class

Constructors

FeedingTimer(int hour, int minute, int second, List<int> repeatDays, int servingCount, int enabled)

Properties

enabled int
final
hashCode int
The hash code for this object.
no setterinherited
hour int
final
minute int
final
repeatDays List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second int
final
servingCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited