EventService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
allEvents(String deviceId, String date)
→ Future<Resp<Events?>>
-
-
catagories(String deviceId)
→ Future<Resp<Categories>>
-
-
catagoriesOfList(List<String> deviceIdList)
→ Future<Resp<Categories>>
-
-
currentNotificationSettings(String deviceId)
→ Future<Resp<RemotePushConfigure>>
-
-
delete(String eventId, {bool global = false})
→ Future<Ret>
-
-
deleteList(List<String> eventIdList, {bool global = false})
→ Future<Ret>
-
-
deleteRange(String deviceId, int startTimestampInSecond, int endTimestampInSecond, {bool global = false})
→ Future<Ret>
-
-
deleteRangeOfList(List<String> deviceIdList, int startTimestampInSecond, int endTimestampInSecond, {bool global = false})
→ Future<Ret>
-
-
event(String eventId)
→ Future<Resp<Event?>>
-
-
eventsByPage(String deviceId, String date, int offset, {int limit = 30, List<String>? catagoriesLabel})
→ Future<Resp<List<Event>?>>
-
-
eventsByPageOfList(List<String> deviceIdList, String date, int offset, {int limit = 30, List<String>? catagoriesLabel})
→ Future<Resp<List<Event>?>>
-
-
listEventsByPageOfDays(String deviceId, String startDate, String endDate, int offset, {int limit = 30, List<String>? catagoriesLabel})
→ Future<Resp<List<Event>?>>
-
-
updateNotificationSettings(String deviceId, LocalPushConfigure configure)
→ Future<Ret>
-